package com.rayfocus.aws.lambda.videotranscoder;

import java.util.Arrays;
import java.util.List;

import com.amazonaws.regions.Region;
import com.amazonaws.regions.Regions;
import com.amazonaws.services.elastictranscoder.AmazonElasticTranscoderClient;
import com.amazonaws.services.elastictranscoder.model.CreateJobOutput;
import com.amazonaws.services.elastictranscoder.model.CreateJobRequest;
import com.amazonaws.services.elastictranscoder.model.JobInput;
import com.amazonaws.services.lambda.runtime.Context;
import com.amazonaws.services.lambda.runtime.RequestHandler;

import com.amazonaws.services.lambda.runtime.events.S3Event;

@SuppressWarnings("deprecation")
public class TranscodeJobCreator implements RequestHandler<S3Event, Object> {

	private static final AmazonElasticTranscoderClient elasticTranscoder;

	private static final String TRANSCODE_GENERIC_1080p_PRESET_ID = "1351620000001-000001";
	private static final String TRANSCODE_GENERIC_720p_PRESET_ID = "1351620000001-000010";
	private static final String TRANSCODE_WEB_720p_PRESET_ID = "1351620000001-100070";

	private static final String OUTPUT_KEY_PREFIX = "output-videos/";
	private static final String ELASTIC_TRANSCODER_PIPELINE_ID = "ELASTIC_TRANSCODER_PIPELINE_ID";
	private static final String OUTPUT_VIDEO_FORMAT = "OUTPUT_VIDEO_FORMAT"; 

	static {
		//elasticTranscoder = new AmazonElasticTranscoderClient(AwsAuth.getProfileCredentials("aws-access"));
		//elasticTranscoder = new AmazonElasticTranscoderClient(AwsAuth.getProfileCredentials());
		elasticTranscoder = new AmazonElasticTranscoderClient();
		Region usEast1 = Region.getRegion(Regions.US_EAST_1);
		elasticTranscoder.setRegion(usEast1);
	}

	public Object handleRequest(S3Event input, Context context) {
		context.getLogger().log("Input: " + input);
		context.getLogger().log("PipelineId: " + System.getenv(ELASTIC_TRANSCODER_PIPELINE_ID));
		
		// Get the S3 input object key for Transcoder Job
		String inputKey = input.getRecords().get(0).getS3().getObject().getKey();
		inputKey = inputKey.replaceAll(" ", "+");
		context.getLogger().log("Input Key: " + inputKey);
		
		// Create the Transcoder Job input
		JobInput transcoderJobInput = new JobInput().withKey(inputKey);

		// Create the output key for Transcoder Job
		String outputKey = inputKey.split("\\.")[0];
		
		// Loggers
		context.getLogger().log("OutputKey: " + outputKey);
		
		// Configure the Transcoder Job output
		CreateJobOutput generic1080p = new CreateJobOutput().withKey(outputKey + "-1080p" + "." + System.getenv(OUTPUT_VIDEO_FORMAT))
				.withPresetId(TRANSCODE_GENERIC_1080p_PRESET_ID);
		CreateJobOutput generic720p = new CreateJobOutput().withKey(outputKey + "-720p" + "." + System.getenv(OUTPUT_VIDEO_FORMAT))
				.withPresetId(TRANSCODE_GENERIC_720p_PRESET_ID);
		CreateJobOutput web720p = new CreateJobOutput().withKey(outputKey + "-web-720p" + "." + System.getenv(OUTPUT_VIDEO_FORMAT))
				.withPresetId(TRANSCODE_WEB_720p_PRESET_ID);
		List<CreateJobOutput> transcoderJobOutputs = Arrays.asList(generic1080p, generic720p, web720p);

		// Create the Transcoder Job request
		CreateJobRequest createJobRequest = new CreateJobRequest()
				.withPipelineId(System.getenv(ELASTIC_TRANSCODER_PIPELINE_ID)).withInput(transcoderJobInput)
				.withOutputKeyPrefix(OUTPUT_KEY_PREFIX).withOutputs(transcoderJobOutputs);

		// Create the Transcoder Job
		elasticTranscoder.createJob(createJobRequest);
		
		return "{'status':'done'}";
	}
}